fl_wx library

Classes

AuthType
The base class for all AuthType
AutoDeduct
Auto Deduct
Browser
Open WeChat browser with given url.
BusinessView
see * https://pay.weixin.qq.com/wiki/doc/apiv3_partner/Offline/apis/chapter6_2_1.shtml
CustomerServiceChat
Customer service chat, known as "微信客服" in WeChat
Fluwx
FlWX
FlWXCallbackParams
HongKongWallet
request Hong Kong Wallet payment with WeChat. Read the official document for more detail.
Invoice
Inovice
MiniProgram
open mini-program see WXMiniProgramType
NormalAuth
The WeChat-Login is under Auth-2.0 This method login with native WeChat app. For users without WeChat app, please use QRCode instead This method only supports getting AuthCode,this is first step to login with WeChat Once AuthCode got, you need to request Access_Token For more information please visit:
OpenType
The target you want to open.
Payment
request payment with WeChat. Read the official document for more detail. timestamp is int because timestamp will be mapped to Unit32.
PayType
PhoneLogin
Currently only support iOS
QRCode
Sometimes WeChat is not installed on users's devices.However we can request a QRCode so that we can get AuthCode by scanning the QRCode All required params must not be null or empty schemeData only works on iOS see * https://open.weixin.qq.com/cgi-bin/showdocument?action=dir_list&t=resource/res_list&verify=1&id=215238808828h4XN&token=&lang=zh_CN
RankList
Rank list
SubscribeMessage
See *https://developers.weixin.qq.com/doc/oplatform/Mobile_App/One-time_subscription_info.html for more detail
WeChatApp
Just open WeChat app.
WeChatAuthByQRCodeFinishedResponse
The response when auth by QRCode finished.
WeChatAuthGotQRCodeResponse
qrCode in memory.
WeChatAuthResponse
The response when auth finished.
WeChatFile
WeChatImageToShare
WeChatLaunchFromWXRequest
获取微信打开App时携带的参数
WeChatLaunchMiniProgramResponse
The response when launching mini program finished.
WeChatOpenBusinessViewResponse
The response when open business view finished.
WeChatOpenBusinessWebviewResponse
The response when open business webview finished.
WeChatOpenCustomerServiceChatResponse
The response when customer service chat finished.
WeChatOpenInvoiceResponse
WeChatPaymentResponse
The response when payment finished.
WeChatQRCodeScannedResponse
WeChatResponse
WeChatShareEmojiModel
WeChatShareFileModel
source the file you want to share, source.suffix is necessary on iOS. scene can't be WeChatScene.TIMELINE, otherwise, sharing nothing. send files to WeChat
WeChatShareImageModel
source the image you want to send to WeChat scene the target you want to send
WeChatShareMiniProgramModel
hdImageData only works on iOS, not sure the relationship the default value is MINI_PROGRAM_TYPE_RELEASE scene on supports WeChatScene.session for mini program sharing.
WeChatShareModel
Base class for all share models
WeChatShareMusicModel
if musicUrl and musicLowBandUrl are both provided, only musicUrl will be used.
WeChatShareResponse
The response when sharing finished.
WeChatShareTextModel
source the text you want to send to WeChat scene the target you want to send
WeChatShareVideoModel
if videoUrl and videoLowBandUrl are both provided, only videoUrl will be used.
WeChatShareWebPageModel
webPage url you want to send to wechat thumbnail logo of your website
WeChatShowMessageFromWXRequest
获取微信打开App时携带的参数
WeChatSubscribeMsgResponse
The response when subscribe message finished.
WXTokenModel
WXUserModel

Mixins

FluwxCancelable
A mixin that provides a method to cancel an operation.

Extensions

ExtensionMap on Map

Constants

defaultSuffixJpeg → const String
defaultSuffixTxt → const String

Typedefs

FlWeChatAuthResponseCallback = FutureOr<void> Function(WeChatAuthResponse response)
Auth 回调
FlWeChatAuthResponseTokenCallback = FutureOr<void> Function(WeChatAuthResponse response, WXTokenModel token)
Auth token 回调
FlWeChatAuthResponseUserinfoCallback = FutureOr<void> Function(WeChatAuthResponse response, WXTokenModel token, WXUserModel userInfo)
Auth userinfo 回调
FlWeChatLaunchFromWXRequestCallback = FutureOr<void> Function(WeChatLaunchFromWXRequest response)
LaunchFromWX 回调
FlWeChatOpenBusinessViewResponseCallback = FutureOr<void> Function(WeChatOpenBusinessViewResponse response)
WeChatOpenBusinessView 回调
FlWeChatOpenBusinessWebViewResponseCallback = FutureOr<void> Function(WeChatOpenBusinessWebviewResponse response)
OpenBusinessWebView 回调
FlWeChatPayResponseCallback = FutureOr<void> Function(WeChatPaymentResponse response)
支付结果回调
FlWeChatPayResponseResultCallback = FutureOr<void> Function()
支持成功
FlWeChatResponseCallback = FutureOr<void> Function(WeChatResponse response)
FlWeChatShareResponseCallback = FutureOr<void> Function(WeChatShareResponse response)
Share 回调
FlWXCallbackString = FutureOr<void> Function(String msg)
FlWXHTTPCallback = FutureOr<String?> Function(String url)
http 请求
WeChatResponseSubscriber = void Function(WeChatResponse response)