Fluwx class
Constructors
- Fluwx()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isSupportOpenBusinessView
→ Future<
bool> -
no setter
-
isWeChatInstalled
→ Future<
bool> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addSubscriber(
WeChatResponseSubscriber listener) → FluwxCancelable - Add a subscriber to subscribe responses from WeChat
-
attemptToResumeMsgFromWx(
) → Future< void> - Try to reload data from cold boot. For example, the app is launched by mini program and we can get ext message by calling this.
-
authBy(
{required AuthType which}) → Future< bool> - Login by WeChat.See AuthType for more details.
-
autoDeduct(
{required AutoDeduct data}) → Future< bool> - please read * official docs.
-
clearSubscribers(
) → void - remove all existing
-
getExtMsg(
) → Future< String?> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
{required OpenType target}) → Future< bool> - Open given target. See OpenType for more details
-
pay(
{required PayType which}) → Future< bool> - Pay with WeChat. See PayType
-
registerApi(
{required String appId, bool doOnIOS = true, bool doOnAndroid = true, String? universalLink}) → Future< bool> -
It's ok if you register multi times.
appIdis not necessary. ifdoOnIOSis true ,fluwx will register WXApi on iOS. ifdoOnAndroidis true, fluwx will register WXApi on Android.universalLinkis required if you want to register on iOS. -
removeSubscriber(
WeChatResponseSubscriber listener) → void - remove your subscriber from WeChat
-
selfCheck(
) → Future< void> - Only works on iOS in debug mode. Check if your app can work with WeChat correctly. Please make sure registerApi returns true before self check.
-
Share your requests to WeChat.
This depends on the actual type of
what. -
stopAuthByQRCode(
) → Future< bool> - Stop QR service
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited