WeChatLaunchMiniProgramResponse class

The response when launching mini program finished.

Inheritance

Properties

errCode int?
finalinherited
errStr String?
finalinherited
extMsg String?
final
hashCode int
The hash code for this object.
no setterinherited
isSuccessful bool
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRecord() Record
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited