FlWXCallbackParams class
Constructors
- FlWXCallbackParams({FlWXCallbackString? onToast, FlWXCallbackString? onLog, FlWXHTTPCallback? onHttp})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- onHttp → FlWXHTTPCallback?
-
http 请求 返回 json
final
- onLog → FlWXCallbackString?
-
日志 打印
final
- onToast → FlWXCallbackString?
-
toast 显示
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited